"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
var docregistry_1 = require("@jupyterlab/docregistry");
var coreutils_1 = require("@phosphor/coreutils");
var disposable_1 = require("@phosphor/disposable");
var renderer_1 = require("./renderer");
var manager_1 = require("./manager");
var output_1 = require("./output");
var base = require("@jupyter-widgets/base");
var widgets = require("@jupyter-widgets/controls");
widgets['OutputModel'] = output_1.OutputModel;
widgets['OutputView'] = output_1.OutputView;
require("@jupyter-widgets/base/css/index.css");
require("@jupyter-widgets/controls/css/widgets-base.css");
var WIDGET_MIMETYPE = 'application/vnd.jupyter.widget-view+json';
/**
 * The token identifying the JupyterLab plugin.
 */
exports.INBWidgetExtension = new coreutils_1.Token('jupyter.extensions.nbWidgetManager');
var NBWidgetExtension = (function () {
    function NBWidgetExtension() {
        this._registry = [];
    }
    /**
     * Create a new extension object.
     */
    NBWidgetExtension.prototype.createNew = function (nb, context) {
        var wManager = new manager_1.WidgetManager(context, nb.rendermime);
        wManager.register({
            name: '@jupyter-widgets/base',
            version: base.JUPYTER_WIDGETS_VERSION,
            exports: {
                WidgetModel: base.WidgetModel,
                WidgetView: base.WidgetView,
                DOMWidgetView: base.DOMWidgetView,
                DOMWidgetModel: base.DOMWidgetModel,
                LayoutModel: base.LayoutModel,
                LayoutView: base.LayoutView,
            }
        });
        wManager.register({
            name: '@jupyter-widgets/controls',
            version: widgets.JUPYTER_WIDGETS_VERSION,
            exports: widgets
        });
        this._registry.forEach(function (data) { return wManager.register(data); });
        var wRenderer = new renderer_1.WidgetRenderer(wManager);
        nb.rendermime.addRenderer({ mimeType: WIDGET_MIMETYPE, renderer: wRenderer }, 0);
        return new disposable_1.DisposableDelegate(function () {
            if (nb.rendermime) {
                nb.rendermime.removeRenderer(WIDGET_MIMETYPE);
            }
            wRenderer.dispose();
            wManager.dispose();
        });
    };
    /**
     * Register a widget module.
     */
    NBWidgetExtension.prototype.registerWidget = function (data) {
        this._registry.push(data);
    };
    return NBWidgetExtension;
}());
exports.NBWidgetExtension = NBWidgetExtension;
/**
 * The widget manager provider.
 */
var widgetManagerProvider = {
    id: 'jupyter.extensions.nbWidgetManager',
    provides: exports.INBWidgetExtension,
    requires: [docregistry_1.IDocumentRegistry],
    activate: activateWidgetExtension,
    autoStart: true
};
exports.default = widgetManagerProvider;
/**
 * Activate the widget extension.
 */
function activateWidgetExtension(app, registry) {
    var extension = new NBWidgetExtension();
    registry.addWidgetExtension('Notebook', extension);
    return extension;
}
